@@ -10,21 +10,30 @@ class ElastalertWebhook(WebhookBase):
         try:
             # Default parameters
             print("payload: "+str(payload))
-            resource = payload['kubernetes']['pod_name']
-            environment = 'Production'
-            res = payload['event']
-            event = res['eventName']
-            severity =res['severity'].lower()
-            group ='Elastalert'
-            text = res['message']
+            rawData = str(payload)
+            resource = payload.get('queryKey','N/A')
+            environment = payload.get('fedUniqueName','N/A')
+            res = payload.get('event','N/A')
+            group = payload.get('group','N/A')
+            if(res!="N/A"):
+                event = res.get('eventName','N/A')
+                severity =res.get('severity','N/A').lower()
+                text = res.get('message','N/A')
+            else:
+                event = "N/A"
+                severity = "N/A"
+                text = "N/A"
             tags = []
             attributes = {}
-            createTime = payload['@timestamp']
+            attributes['potentialImpact']=payload.get('potentialImpact','N/A')
+            attributes['remedy']=payload.get('remedy','N/A')
+            attributes['rawData']=str(payload)
+            createTime = payload.get('@timestamp','N/A')
             try:
-                origin = res['resourceXpath']
+                origin = payload['kubernetes']['host']
             except Exception as e:
                 print("origin not defined")
-                origin = ' '
+                origin = 'N/A'
         except Exception as e:
             print("Error reading payload: "+str(e)) 
 
@@ -32,14 +41,15 @@ class ElastalertWebhook(WebhookBase):
             resource = resource,
             event = event,
             severity = severity,
-            service = ['example.com'],
+            service = [],
             group = group,
             text = text,
             tags = tags,
             origin = origin,
             createTime = createTime,
             attributes = attributes,
-            environment = environment
+            environment = environment,
+            rawData = rawData
         #     environment=payload.get('environment', environment),
         #     severity=payload.get('severity', severity),
         #     service=['fail2ban'],
